edt2ics
=======

``edt2ics`` is a library and command-line tool for CS students at Paris Diderot
University to generate iCalendar files from the online HTML schedules.

Install
-------

::
    pip install p7edt2ics

Usage
-----

::
    edt2ics <year>

Where ``year`` is one of: ``L3``, ``M1``, ``M2``.
